#include "DeerRender/Mesh.h"

namespace Deer {
	void DataStore::createExampleMeshData() {
		/* 
		MeshData meshData;

		meshData.vertexCount = 3;
		// Triangle
		meshData.vertexPositionsData = new VertexPosition[3]{
		    VertexPosition(PositionAxis(0 * 128, 0), PositionAxis(0 + 128, 0),
		                   PositionAxis(0 * 128, 0)),
		    VertexPosition(PositionAxis(0 * 128, 64), PositionAxis(0 + 128, 0),
		                   PositionAxis(1 * 128, 0)),
		    VertexPosition(PositionAxis(1 * 128, 0), PositionAxis(0 + 128, 0),
		                   PositionAxis(0 * 128, 0))};
		meshData.vertexNormalData =
		    new VertexNormal[3]{VertexNormal(0, 64, 0), VertexNormal(0, 64, 0),
		                        VertexNormal(0, 64, 0)};

		meshData.indexCount = 3;
		meshData.indexData = new uint16_t[3]{0, 1, 2};

		DataStore::saveModel(meshData, "exampleTriangle");
		DataStore::saveBinModel(meshData, "exampleTriangle");*/
	}
}  // namespace Deer